@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%%
-%%% Copyright (C) 2002-2022 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@
 -module(xmpp_sasl).
 -author('alexey@process-one.net').
 
--export([server_new/4, server_start/4, server_step/2,
+-export([server_new/4, server_start/5, server_step/2,
 	 listmech/0, format_error/2]).
 
 %% TODO: write correct types for these callbacks
@@ -54,10 +54,12 @@
 			unsupported_mechanism | nodeprep_failed |
 			empty_username | aborted.
 
+-type channel_bindings() :: none | #{binary() => binary()}.
+
 -export_type([mechanism/0, error_reason/0,
 	      sasl_state/0, sasl_return/0, sasl_property/0]).
 
--callback mech_new(binary(), xmpp_socket:socket(),
+-callback mech_new(binary(), channel_bindings(), list(binary()),
 		   binary(),
 		   get_password_fun(),
 		   check_password_fun(),
@@ -102,13 +104,14 @@ server_new(ServerHost, GetPassword, CheckPassword, CheckPasswordDigest) ->
 		check_password = CheckPassword,
 		check_password_digest = CheckPasswordDigest}.
 
--spec server_start(sasl_state(), mechanism(), binary(), xmpp_socket:socket()) -> sasl_return().
-server_start(State, Mech, ClientIn, Socket) ->
+-spec server_start(sasl_state(), mechanism(), binary(), channel_bindings(),
+  list(binary()) | undefined) -> sasl_return().
+server_start(State, Mech, ClientIn, ChannelBindings, Mechs) ->
     case get_mod(Mech) of
 	undefined ->
 	    {error, unsupported_mechanism, <<"">>};
 	Module ->
-	    MechState = Module:mech_new(Mech, Socket,
+	    MechState = Module:mech_new(Mech, ChannelBindings, Mechs,
 					State#sasl_state.server_host,
 					State#sasl_state.get_password,
 					State#sasl_state.check_password,
